@@ -27,19 +27,31 @@ lav_fit_3 <- suppressWarnings(lavaan::cfa(lav_mod_1, sample.cov =
 om_lav_gr <- .OMEGA_LAVAAN(lav_fit_3, g_name = "g", group_names = c("Some",
                                                                     "Others"))
 
+lav_mod_ho <- 'F1 =~ V1 + V2 + V3 + V4 + V5 + V6
+               F2 =~ V7 + V8 + V9 + V10 + V11 + V12
+               F3 =~ V13 + V14 + V15 + V16 + V17 + V18
+               g =~ F1 + F2 + F3'
+lav_fit_ho <- suppressWarnings(lavaan::cfa(lav_mod_ho,
+                                           sample.cov = test_models$baseline$cormat,
+                                           sample.nobs = 500, estimator = "ml"))
+om_lav_ho <- suppressMessages(.OMEGA_LAVAAN(lav_fit_ho, g_name = "g"))
+
 test_that("output class and dimensions are correct", {
   expect_is(om_lav_bi, "OMEGA")
   expect_is(om_lav_1, "OMEGA")
+  expect_is(om_lav_ho, "OMEGA")
   expect_is(om_lav_gr, "OMEGA")
 
   expect_output(str(om_lav_bi), "List of 2")
   expect_output(str(om_lav_1), "OMEGA")
+  expect_output(str(om_lav_ho), "List of 2")
   expect_output(str(om_lav_gr), "List of 2")
 })
 
 test_that("output is correct (including group names for multiple groups)", {
   expect_equal(rowSums(om_lav_bi[, 2:3]), om_lav_bi[, 1], tolerance = 1e-3)
   expect_equal(om_lav_1[1], 0.868, tolerance = 1e-3)
+  expect_equal(rowSums(om_lav_ho[, 2:3]), om_lav_ho[, 1], tolerance = 1e-3)
   expect_equal(rowSums(om_lav_gr$Some[, 2:3]), om_lav_gr$Some[, 1], tolerance = 1e-3)
   expect_equal(rowSums(om_lav_gr$Others[, 2:3]), om_lav_gr$Others[, 1], tolerance = 1e-3)
 })
@@ -54,27 +66,30 @@ lav_fit_NA <- suppressWarnings(lavaan::cfa(lav_mod_NA,
                                            sample.cov = test_models$baseline$cormat,
                                            sample.nobs = 500, estimator = "ml"))
 
-lav_mod_hier <- 'F1 =~ V1 + V2 + V3 + V4 + V5 + V6
+lav_mod_inv <- 'F1 =~ V1 + V2 + V3 + V4 + V5 + V6
+               F2 =~ V7 + V8 + V9 + V10 + V11 + V12
+               F3 =~ V13 + V14 + V15 + V16 + V17 + V18'
+lav_fit_inv <- suppressWarnings(lavaan::cfa(lav_mod_inv,
+                                           sample.cov = test_models$baseline$cormat,
+                                           sample.nobs = 500, estimator = "ml"))
+
+lav_mod_bi_red <- 'F1 =~ V1 + V2 + V3 + V4 + V5 + V6
                F2 =~ V7 + V8 + V9 + V10 + V11 + V12
                F3 =~ V13 + V14 + V15 + V16 + V17 + V18
-               g =~ F1 + F2 + F3'
-lav_fit_hier <- suppressWarnings(lavaan::cfa(lav_mod_hier,
-                                             sample.cov = test_models$baseline$cormat,
-                                             sample.nobs = 500, estimator = "ml"))
-
-lav_mod_hier2 <- 'F1 =~ V1 + V2 + V3 + V4 + V5 + V6
-               F2 =~ V7 + V8 + V9 + V10 + V11 + V12 + V13
-               F3 =~ V13 + V14 + V15 + V16 + V17 + V18
-               g =~ F1 + F2 + F3'
-lav_fit_hier2 <- suppressWarnings(lavaan::cfa(lav_mod_hier2,
+               g =~ V1 + V2 + V3 + V4 + V5 + V6 + V7 + V8 + V9 + V10 +
+                    V13 + V14 + V15 + V16 + V17 + V18'
+lav_fit_bi_red <- suppressWarnings(lavaan::cfa(lav_mod_bi_red,
                                               sample.cov = test_models$baseline$cormat,
-                                              sample.nobs = 500, estimator = "ml"))
+                                              sample.nobs = 500, estimator = "ml",
+                                              orthogonal = TRUE))
 
 test_that("errors are thrown correctly", {
   expect_error(.OMEGA_LAVAAN(lav_fit_NA, g_name = "g"), " Some loadings are NA or NaN. No omegas are computed.\n")
+  expect_error(.OMEGA_LAVAAN(lav_fit_1, g_name = "fu"), " Could not find the specified name of the general factor in the entered lavaan solution. Please check the spelling.\n")
   expect_message(.OMEGA_LAVAAN(lav_fit_2), " Model contained a single factor. Only omega total is returned.\n")
-  expect_error(.OMEGA_LAVAAN(lav_fit_hier, g_name = "g"), " You did not fit a bifactor model. Omegas cannot be computed. Either provide a bifactor model or a model with a single factor.\n")
-  expect_message(.OMEGA_LAVAAN(lav_fit_hier2, g_name = "g"), " Some variables have less than two loadings. Did you really enter a bifactor model? Either provide a bifactor model or a model with a single factor.\n", fixed = TRUE)
+  expect_message(.OMEGA_LAVAAN(lav_fit_ho, g_name = "g"), " The general factor you specified is a second-order factor. Omegas are found on the Schmid-Leiman transformed second-order solution.\n")
+  expect_error(.OMEGA_LAVAAN(lav_fit_inv, g_name = "F3"), " Your lavaan input is invalid, no omegas are computed. Either provide a bifactor model, a second-order model, or a model with a single factor.\n")
+  expect_message(.OMEGA_LAVAAN(lav_fit_bi_red, g_name = "g"), " Some variables have less than two loadings. Did you really enter a bifactor model? Either provide a bifactor model, a second-order model, or a model with a single factor.\n", fixed = TRUE)
 })
 
 ## Tests for .OMEGA_FLEX -------
@@ -87,6 +102,12 @@ om_sl <- .OMEGA_FLEX(sl_mod, type = "EFAtools", factor_corres = rep(c(3, 2, 1),
                                                               each = 6),
                      variance = "correlation")
 
+# Explicit factor names
+om_sl_named <- .OMEGA_FLEX(sl_mod, type = "EFAtools",
+                           fac_names = c("Fa1", "Fa2", "Fa3"),
+                           factor_corres = rep(c(3, 2, 1), each = 6),
+                           variance = "correlation")
+
 ## Use with an output from the psych::schmid function, with type psych
 schmid_mod <- psych::schmid(test_models$baseline$cormat, nfactors = 3,
                             n.obs = 500, fm = "pa", rotate = "Promax")
@@ -111,12 +132,14 @@ om_man_2 <- .OMEGA_FLEX(model = NULL, type = "EFAtools", var_names = rownames(sl
 
 test_that("output class and dimensions are correct", {
   expect_is(om_sl, "OMEGA")
+  expect_is(om_sl_named, "OMEGA")
   expect_is(om_schmid_1, "OMEGA")
   expect_is(om_schmid_2, "OMEGA")
   expect_is(om_man_1, "OMEGA")
   expect_is(om_man_2, "OMEGA")
 
   expect_output(str(om_sl), "List of 2")
+  expect_output(str(om_sl_named), "List of 2")
   expect_output(str(om_schmid_1), "List of 2")
   expect_output(str(om_schmid_2), "List of 2")
   expect_output(str(om_man_1), "List of 2")
@@ -125,12 +148,14 @@ test_that("output class and dimensions are correct", {
 
 test_that("output is correct", {
   expect_equal(rowSums(om_sl[2:4, 2:3]), om_sl[2:4, 1], tolerance = 1e-3)
+  expect_equal(rowSums(om_sl_named[2:4, 2:3]), om_sl_named[2:4, 1], tolerance = 1e-3)
   expect_equal(rowSums(om_schmid_1[2:4, 2:3]), om_schmid_1[2:4, 1], tolerance = 1e-3)
   expect_equal(rowSums(om_schmid_2[2:4, 2:3]), om_schmid_2[2:4, 1], tolerance = 1e-3)
   expect_equal(rowSums(om_man_1[2:4, 2:3]), om_man_1[2:4, 1], tolerance = 1e-3)
   expect_equal(rowSums(om_man_2[2:4, 2:3]), om_man_2[2:4, 1], tolerance = 1e-3)
 
   expect_gte(om_sl[1, 1], sum(om_sl[1, 2:3]))
+  expect_gte(om_sl_named[1, 1], sum(om_sl_named[1, 2:3]))
   expect_gte(om_schmid_1[1, 1], sum(om_schmid_1[1, 2:3]))
   expect_gte(om_schmid_2[1, 1], sum(om_schmid_2[1, 2:3]))
   expect_gte(om_man_1[1, 1], sum(om_man_1[1, 2:3]))
@@ -165,6 +190,6 @@ test_that("errors are thrown correctly", {
 })
 
 rm(lav_mod_1, lav_fit_1, om_lav_bi, lav_mod_2, lav_fit_2, om_lav_1, lav_fit_3,
-   om_lav_gr, lav_mod_NA, lav_fit_NA, lav_mod_hier, lav_fit_hier,
-   lav_mod_hier2, lav_fit_hier2, efa_mod, sl_mod, om_sl, schmid_mod, om_schmid_1,
-   om_schmid_2, om_man_1, om_man_2)
+   om_lav_gr, lav_mod_ho, lav_fit_ho, om_lav_ho, lav_mod_NA, lav_fit_NA,
+   lav_mod_inv, lav_fit_inv, lav_mod_bi_red, lav_fit_bi_red, efa_mod, sl_mod,
+   om_sl, om_sl_named, schmid_mod, om_schmid_1, om_schmid_2, om_man_1, om_man_2)
